package HTML::Perlinfo::Credits;
use base qw(Exporter);
our @EXPORT = qw(print_credits);

use HTML::Perlinfo::Common;

sub print_credits {
	 
	        return join '',  "<h1>Perl Credits</h1>\n", 
		# The Holy Keepers of the Pumpkin    
   	        print_table_start(),
		print_table_header(1, "Perl 5 Pumpkings"),
		print_table_row(1, "Larry Wall, Andy Dougherty, Tom Christiansen, Charles Bailey, Nick Ing-Simmons, Chip Salzenberg, Tim Bunce, Malcolm Beattie, Gurusamy Sarathy, Graham Barr, Jarkko Hietaniemi "),
		print_table_end(),
 	

		# Design & Concept 
		print_table_start(),
		print_table_header(1, "Language Design &amp; Concept"),
		print_table_row(1, "Larry Wall"),
		print_table_end(),

		# Perl 5 Language 
		print_table_start(),
		print_table_colspan_header(2, "Perl 5 Authors"),
		print_table_header(2, "Contribution", "Authors"),
		print_table_row(2, "XS Interface Language", "Dean Roehrich"),
		print_table_row(2, "POD Format Language", "Larry Wall"),
		print_table_row(2, "Mac OS Port", "Matthias Neeracher"),
		print_table_row(2, "Win32 Port", "ActiveState with assistance from Microsoft Inc."),
		print_table_row(2, "Other contributors", "Patch submitters and other contributers are listed in the authors file in the source distribution"),
		print_table_end(),
	

		# Modules 
		print_table_start(),
		print_table_colspan_header(2, "Core Module Authors"),
		print_table_header(2, "Module", "Authors"),
	      
	        # This is the list for 5.8.3. 	
		print_table_row(2, "AnyDBM_File","The Perl5 Porters Mailing List"),
		print_table_row(2, "Attribute::Handlers","Arthur Bergman"),
		print_table_row(2, "AutoLoader","The Perl5 Porters Mailing List"),
		print_table_row(2, "AutoSplit","The Perl5 Porters Mailing List"),
		print_table_row(2, "B","Malcolm Beattie"),
		print_table_row(2, "B::Asmdata","Nicholas Clark"),
		print_table_row(2, "B::Assembler","Nicholas Clark"),
		print_table_row(2, "B::Bblock","Nicholas Clark"),
		print_table_row(2, "B::Bytecode","Nicholas Clark"),
		print_table_row(2, "B::C","Nicholas Clark"),
		print_table_row(2, "B::CC","Nicholas Clark"),
		print_table_row(2, "B::Concise","Nicholas Clark"),
		print_table_row(2, "B::Debug","Nicholas Clark"),
		print_table_row(2, "B::Deparse","Nicholas Clark"),
		print_table_row(2, "B::Disassembler","Nicholas Clark"),
		print_table_row(2, "B::Lint","Nicholas Clark"),
		print_table_row(2, "B::Showlex","Nicholas Clark"),
		print_table_row(2, "B::Stackobj","Nicholas Clark"),
		print_table_row(2, "B::Stash","Nicholas Clark"),
		print_table_row(2, "B::Terse","Nicholas Clark"),
		print_table_row(2, "B::Xref","Nicholas Clark"),
		print_table_row(2, "Benchmark","The Perl5 Porters Mailing List"),
		print_table_row(2, "ByteLoader","Nicholas Clark"),
		print_table_row(2, "CGI","Lincoln D. Stein"),
		print_table_row(2, "CGI::Carp","The CGI-Perl Developers mailing list"),
		print_table_row(2, "CGI::Cookie","Lincoln D. Stein"),
		print_table_row(2, "CGI::Fast","Lincoln D. Stein"),
		print_table_row(2, "CGI::Pretty","Lincoln D. Stein"),
		print_table_row(2, "CGI::Push","Lincoln D. Stein"),
		print_table_row(2, "CGI::Util","Lincoln D. Stein"),
		print_table_row(2, "CPAN","Andreas J. Koenig"),
		print_table_row(2, "CPAN::FirstTime","Andreas J. Koenig"),
		print_table_row(2, "CPAN::Nox","Andreas J. Koenig"),
		print_table_row(2, "Carp","The Perl5 Porters Mailing List"),
		print_table_row(2, "Class::ISA","Sean M. Burke"),
		print_table_row(2, "Class::Struct","Nicholas Clark"),
		print_table_row(2, "Config","The Perl5 Porters Mailing List"),
		print_table_row(2, "Cwd","The Perl5 Porters Mailing List"),
		print_table_row(2, "DB_File","Paul Marquess"),
		print_table_row(2, "Data::Dumper","Gurusamy Sarathy"),
		print_table_row(2, "Devel::DProf","Dean Roehrich"),
		print_table_row(2, "Devel::PPPort","Marcus Holland-Moritz"),
		print_table_row(2, "Devel::Peek","Ilya Zakharevich"),
		print_table_row(2, "Devel::SelfStubber","Nicholas Clark"),
		print_table_row(2, "Digest","Gisle Aas"),
		print_table_row(2, "Digest::MD5","Gisle Aas"),
		print_table_row(2, "Digest::base","Gisle Aas"),
		print_table_row(2, "DirHandle","Chip Salzenberg"),
		print_table_row(2, "Dumpvalue","Nicholas Clark"),
		print_table_row(2, "DynaLoader","The Perl5 Porters Mailing List"),
		print_table_row(2, "Encode","Dan Kogai"),
		print_table_row(2, "Encode::Alias","Dan Kogai"),
		print_table_row(2, "Encode::Byte","Dan Kogai"),
		print_table_row(2, "Encode::CJKConstants","Dan Kogai"),
		print_table_row(2, "Encode::CN","Dan Kogai"),
		print_table_row(2, "Encode::CN::HZ","Dan Kogai"),
		print_table_row(2, "Encode::Config","Dan Kogai"),
		print_table_row(2, "Encode::EBCDIC","Dan Kogai"),
		print_table_row(2, "Encode::Encoder","Dan Kogai"),
		print_table_row(2, "Encode::Encoding","Dan Kogai"),
		print_table_row(2, "Encode::Guess","Dan Kogai"),
		print_table_row(2, "Encode::JP","Dan Kogai"),
		print_table_row(2, "Encode::JP::H2Z","Dan Kogai"),
		print_table_row(2, "Encode::JP::JIS7","Dan Kogai"),
		print_table_row(2, "Encode::KR","Dan Kogai"),
		print_table_row(2, "Encode::KR::2022_KR","Dan Kogai"),
		print_table_row(2, "Encode::MIME::Header","Dan Kogai"),
		print_table_row(2, "Encode::Symbol","Dan Kogai"),
		print_table_row(2, "Encode::TW","Dan Kogai"),
		print_table_row(2, "Encode::Unicode","Dan Kogai"),
		print_table_row(2, "Encode::Unicode::UTF7","Dan Kogai"),
		print_table_row(2, "English","The Perl5 Porters Mailing List"),
		print_table_row(2, "Env","The Perl5 Porters Mailing List"),
		print_table_row(2, "Errno","The Perl5 Porters Mailing List"),
		print_table_row(2, "Exporter","The Perl5 Porters Mailing List"),
		print_table_row(2, "Exporter::Heavy","Nicholas Clark"),
		print_table_row(2, "ExtUtils::Command","Michael G Schwern"),
		print_table_row(2, "ExtUtils::Command::MM","Michael G Schwern"),
		print_table_row(2, "ExtUtils::Constant","Nicholas Clark"),
		print_table_row(2, "ExtUtils::Embed","Doug MacEachern"),
		print_table_row(2, "ExtUtils::Install","Michael G Schwern"),
		print_table_row(2, "ExtUtils::Installed","Michael G Schwern"),
		print_table_row(2, "ExtUtils::Liblist","Michael G Schwern"),
		print_table_row(2, "ExtUtils::Liblist::Kid","Michael G Schwern"),
		print_table_row(2, "ExtUtils::MM","Michael G Schwern"),
		print_table_row(2, "ExtUtils::MM_Any","Michael G Schwern"),
		print_table_row(2, "ExtUtils::MM_BeOS","Michael G Schwern"),
		print_table_row(2, "ExtUtils::MM_Cygwin","Michael G Schwern"),
		print_table_row(2, "ExtUtils::MM_DOS","Michael G Schwern"),
		print_table_row(2, "ExtUtils::MM_MacOS","Michael G Schwern"),
		print_table_row(2, "ExtUtils::MM_NW5","Michael G Schwern"),
		print_table_row(2, "ExtUtils::MM_OS2","Michael G Schwern"),
		print_table_row(2, "ExtUtils::MM_UWIN","Michael G Schwern"),
		print_table_row(2, "ExtUtils::MM_Unix","Michael G Schwern"),
		print_table_row(2, "ExtUtils::MM_VMS","Michael G Schwern"),
		print_table_row(2, "ExtUtils::MM_Win32","Michael G Schwern"),
		print_table_row(2, "ExtUtils::MM_Win95","Michael G Schwern"),
		print_table_row(2, "ExtUtils::MY","Michael G Schwern"),
		print_table_row(2, "ExtUtils::MakeMaker","The MakeMaker mailing list"),
		print_table_row(2, "ExtUtils::MakeMaker::bytes","Nicholas Clark"),
		print_table_row(2, "ExtUtils::MakeMaker::vmsish","Nicholas Clark"),
		print_table_row(2, "ExtUtils::Manifest","The MakeMaker mailing list"),
		print_table_row(2, "ExtUtils::Mkbootstrap","Michael G Schwern"),
		print_table_row(2, "ExtUtils::Mksymlists","Michael G Schwern"),
		print_table_row(2, "ExtUtils::Packlist","Michael G Schwern"),
		print_table_row(2, "ExtUtils::XSSymSet","Nicholas Clark"),
		print_table_row(2, "ExtUtils::testlib","Michael G Schwern"),
		print_table_row(2, "Fatal","Nicholas Clark"),
		print_table_row(2, "Fcntl","Jarkko Hietaniemi"),
		print_table_row(2, "File::Basename","The Perl5 Porters Mailing List"),
		print_table_row(2, "File::CheckTree","The Perl5 Porters Mailing List"),
		print_table_row(2, "File::Compare","The Perl5 Porters Mailing List"),
		print_table_row(2, "File::Copy","Aaron Sherman"),
		print_table_row(2, "File::DosGlob","Nicholas Clark"),
		print_table_row(2, "File::Find","The Perl5 Porters Mailing List"),
		print_table_row(2, "File::Glob","Tye McQueen"),
		print_table_row(2, "File::Path","The Perl5 Porters Mailing List"),
		print_table_row(2, "File::Spec","Ken Williams"),
		print_table_row(2, "File::Spec::Cygwin","Ken Williams"),
		print_table_row(2, "File::Spec::Epoc","Ken Williams"),
		print_table_row(2, "File::Spec::Functions","Ken Williams"),
		print_table_row(2, "File::Spec::Mac","Ken Williams"),
		print_table_row(2, "File::Spec::OS2","Ken Williams"),
		print_table_row(2, "File::Spec::Unix","Ken Williams"),
		print_table_row(2, "File::Spec::VMS","Ken Williams"),
		print_table_row(2, "File::Spec::Win32","Ken Williams"),
		print_table_row(2, "File::Temp","Tim Jenness"),
		print_table_row(2, "File::stat","Tom Christiansen"),
		print_table_row(2, "FileCache","The Perl5 Porters Mailing List"),
		print_table_row(2, "FileHandle","The Perl5 Porters Mailing List"),
		print_table_row(2, "Filter::Simple","Damian Conway"),
		print_table_row(2, "Filter::Util::Call","Paul Marquess"),
		print_table_row(2, "FindBin","The Perl5 Porters Mailing List"),
		print_table_row(2, "GDBM_File","The Perl5 Porters Mailing List"),
		print_table_row(2, "Getopt::Long","Johan Vromans"),
		print_table_row(2, "Getopt::Std","The Perl5 Porters Mailing List"),
		print_table_row(2, "Hash::Util","Nicholas Clark"),
		print_table_row(2, "I18N::Collate","Jarkko Hietaniemi"),
		print_table_row(2, "I18N::LangTags","Sean M. Burke"),
		print_table_row(2, "I18N::LangTags::List","Sean M. Burke"),
		print_table_row(2, "I18N::Langinfo","Nicholas Clark"),
		print_table_row(2, "IO","Graham Barr"),
		print_table_row(2, "IO::Dir","The Perl5 Porters Mailing List"),
		print_table_row(2, "IO::File","The Perl5 Porters Mailing List"),
		print_table_row(2, "IO::Handle","The Perl5 Porters Mailing List"),
		print_table_row(2, "IO::Pipe","The Perl5 Porters Mailing List"),
		print_table_row(2, "IO::Poll","Graham Barr"),
		print_table_row(2, "IO::Seekable","The Perl5 Porters Mailing List"),
		print_table_row(2, "IO::Select","The Perl5 Porters Mailing List"),
		print_table_row(2, "IO::Socket","The Perl5 Porters Mailing List"),
		print_table_row(2, "IO::Socket::INET","Graham Barr"),
		print_table_row(2, "IO::Socket::UNIX","Graham Barr"),
		print_table_row(2, "IPC::Msg","Graham Barr"),
		print_table_row(2, "IPC::Open2","The Perl5 Porters Mailing List"),
		print_table_row(2, "IPC::Open3","The Perl5 Porters Mailing List"),
		print_table_row(2, "IPC::Semaphore","Graham Barr"),
		print_table_row(2, "IPC::SysV","The Perl5 Porters Mailing List"),
		print_table_row(2, "JNI","Nicholas Clark"),
		print_table_row(2, "JPL::AutoLoader","Nicholas Clark"),
		print_table_row(2, "JPL::Class","Nicholas Clark"),
		print_table_row(2, "JPL::Compile","Nicholas Clark"),
		print_table_row(2, "List::Util","Graham Barr"),
		print_table_row(2, "Locale::Constants","Neil Bowers"),
		print_table_row(2, "Locale::Country","Neil Bowers"),
		print_table_row(2, "Locale::Currency","Neil Bowers"),
		print_table_row(2, "Locale::Language","Neil Bowers"),
		print_table_row(2, "Locale::Maketext","Sean M. Burke"),
		print_table_row(2, "Locale::Maketext::Guts","Sean M. Burke"),
		print_table_row(2, "Locale::Maketext::GutsLoader","Sean M. Burke"),
		print_table_row(2, "Locale::Script","Neil Bowers"),
		print_table_row(2, "MIME::Base64","Gisle Aas"),
		print_table_row(2, "MIME::QuotedPrint","Gisle Aas"),
		print_table_row(2, "Math::BigFloat","Tels"),
		print_table_row(2, "Math::BigFloat::Trace","Tels"),
		print_table_row(2, "Math::BigInt","Tels"),
		print_table_row(2, "Math::BigInt::Calc","Tels"),
		print_table_row(2, "Math::BigInt::CalcEmu","Tels"),
		print_table_row(2, "Math::BigInt::Trace","Tels"),
		print_table_row(2, "Math::BigRat","Tels"),
		print_table_row(2, "Math::Complex","Raphael Manfredi"),
		print_table_row(2, "Math::Trig","John A.R. Williams"),
		print_table_row(2, "Memoize","Mark Jason Dominus"),
		print_table_row(2, "Memoize::AnyDBM_File","Mark Jason Dominus"),
		print_table_row(2, "Memoize::Expire","Mark Jason Dominus"),
		print_table_row(2, "Memoize::ExpireFile","Mark Jason Dominus"),
		print_table_row(2, "Memoize::ExpireTest","Mark Jason Dominus"),
		print_table_row(2, "Memoize::NDBM_File","Mark Jason Dominus"),
		print_table_row(2, "Memoize::SDBM_File","Mark Jason Dominus"),
		print_table_row(2, "Memoize::Storable","Mark Jason Dominus"),
		print_table_row(2, "NDBM_File","The Perl5 Porters Mailing List"),
		print_table_row(2, "NEXT","Damian Conway"),
		print_table_row(2, "Net::Cmd","Graham Barr"),
		print_table_row(2, "Net::Config","Graham Barr"),
		print_table_row(2, "Net::Domain","Graham Barr"),
		print_table_row(2, "Net::FTP","Graham Barr"),
		print_table_row(2, "Net::FTP::A","Graham Barr"),
		print_table_row(2, "Net::FTP::E","Graham Barr"),
		print_table_row(2, "Net::FTP::I","Graham Barr"),
		print_table_row(2, "Net::FTP::L","Graham Barr"),
		print_table_row(2, "Net::FTP::dataconn","Graham Barr"),
		print_table_row(2, "Net::NNTP","Graham Barr"),
		print_table_row(2, "Net::Netrc","Graham Barr"),
		print_table_row(2, "Net::POP3","Graham Barr"),
		print_table_row(2, "Net::Ping","Rob Brown"),
		print_table_row(2, "Net::SMTP","Graham Barr"),
		print_table_row(2, "Net::Time","Graham Barr"),
		print_table_row(2, "Net::hostent","Tom Christiansen"),
		print_table_row(2, "Net::netent","Tom Christiansen"),
		print_table_row(2, "Net::protoent","Tom Christiansen"),
		print_table_row(2, "Net::servent","Tom Christiansen"),
		print_table_row(2, "O","Malcolm Beattie"),
		print_table_row(2, "ODBM_File","The Perl5 Porters Mailing List"),
		print_table_row(2, "OS2::DLL","Nicholas Clark"),
		print_table_row(2, "OS2::ExtAttr","Ilya Zakharevich"),
		print_table_row(2, "OS2::PrfDB","Ilya Zakharevich"),
		print_table_row(2, "OS2::Process","Ilya Zakharevich"),
		print_table_row(2, "OS2::REXX","Ilya Zakharevich"),
		print_table_row(2, "Opcode","The Perl5 Porters Mailing List"),
		print_table_row(2, "POSIX","The Perl5 Porters Mailing List"),
		print_table_row(2, "PerlIO","The Perl5 Porters Mailing List"),
		print_table_row(2, "PerlIO::encoding","Nicholas Clark"),
		print_table_row(2, "PerlIO::scalar","Nicholas Clark"),
		print_table_row(2, "PerlIO::via","Nicholas Clark"),
		print_table_row(2, "PerlIO::via::QuotedPrint","Elizabeth Mattijsen"),
		print_table_row(2, "Pod::Checker","Brad Appleton"),
		print_table_row(2, "Pod::Find","Marek Rouchal"),
		print_table_row(2, "Pod::Functions","Nicholas Clark"),
		print_table_row(2, "Pod::Html","Nicholas Clark"),
		print_table_row(2, "Pod::InputObjects","Marek Rouchal"),
		print_table_row(2, "Pod::LaTeX","Tim Jenness"),
		print_table_row(2, "Pod::Man","Kenneth Albanowski"),
		print_table_row(2, "Pod::ParseLink","Russ Allbery"),
		print_table_row(2, "Pod::ParseUtils","Marek Rouchal"),
		print_table_row(2, "Pod::Parser","Brad Appleton"),
		print_table_row(2, "Pod::Perldoc","Sean M. Burke"),
		print_table_row(2, "Pod::Perldoc::BaseTo","Sean M. Burke"),
		print_table_row(2, "Pod::Perldoc::GetOptsOO","Sean M. Burke"),
		print_table_row(2, "Pod::Perldoc::ToChecker","Sean M. Burke"),
		print_table_row(2, "Pod::Perldoc::ToMan","Sean M. Burke"),
		print_table_row(2, "Pod::Perldoc::ToNroff","Sean M. Burke"),
		print_table_row(2, "Pod::Perldoc::ToPod","Sean M. Burke"),
		print_table_row(2, "Pod::Perldoc::ToRtf","Sean M. Burke"),
		print_table_row(2, "Pod::Perldoc::ToText","Sean M. Burke"),
		print_table_row(2, "Pod::Perldoc::ToTk","Sean M. Burke"),
		print_table_row(2, "Pod::Perldoc::ToXml","Sean M. Burke"),
		print_table_row(2, "Pod::PlainText","Marek Rouchal"),
		print_table_row(2, "Pod::Plainer","Nicholas Clark"),
		print_table_row(2, "Pod::Select","Brad Appleton"),
		print_table_row(2, "Pod::Text","Tom Christiansen"),
		print_table_row(2, "Pod::Text::Color","Russ Allbery"),
		print_table_row(2, "Pod::Text::Overstrike","Russ Allbery"),
		print_table_row(2, "Pod::Text::Termcap","Russ Allbery"),
		print_table_row(2, "Pod::Usage","Brad Appleton"),
		print_table_row(2, "SDBM_File","The Perl5 Porters Mailing List"),
		print_table_row(2, "Safe","Malcolm Beattie"),
		print_table_row(2, "Scalar::Util","Graham Barr"),
		print_table_row(2, "Search::Dict","The Perl5 Porters Mailing List"),
		print_table_row(2, "SelectSaver","Chip Salzenberg"),
		print_table_row(2, "SelfLoader","The Perl5 Porters Mailing List"),
		print_table_row(2, "Shell","The Perl5 Porters Mailing List"),
		print_table_row(2, "Socket","Nathan Torkington"),
		print_table_row(2, "Storable","Abhijit Menon-Sen"),
		print_table_row(2, "Switch","Rafael Garcia-Suarez"),
		print_table_row(2, "Symbol","Chip Salzenberg"),
		print_table_row(2, "Sys::Hostname","The Perl5 Porters Mailing List"),
		print_table_row(2, "Sys::Syslog","The Perl5 Porters Mailing List"),
		print_table_row(2, "Term::ANSIColor","Russ Allbery"),
		print_table_row(2, "Term::Cap","Tony Sanders"),
		print_table_row(2, "Term::Complete","The Perl5 Porters Mailing List"),
		print_table_row(2, "Term::ReadLine","Ilya Zakharevich"),
		print_table_row(2, "Test","Sean M. Burke"),
		print_table_row(2, "Test::Builder","Michael G Schwern"),
		print_table_row(2, "Test::Harness","Andy Lester"),
		print_table_row(2, "Test::Harness::Assert","Andy Lester"),
		print_table_row(2, "Test::Harness::Iterator","Andy Lester"),
		print_table_row(2, "Test::Harness::Straps","Andy Lester"),
		print_table_row(2, "Test::More","Michael G Schwern"),
		print_table_row(2, "Test::Simple","Michael G Schwern"),
		print_table_row(2, "Text::Abbrev","The Perl5 Porters Mailing List"),
		print_table_row(2, "Text::Balanced","David Manura"),
		print_table_row(2, "Text::ParseWords","Hal Pomeranz"),
		print_table_row(2, "Text::Soundex","Mark Mielke"),
		print_table_row(2, "Text::Tabs","David Muir Sharnoff"),
		print_table_row(2, "Text::Wrap","David Muir Sharnoff"),
		print_table_row(2, "Thread","The Perl5 Porters Mailing List"),
		print_table_row(2, "Thread::Queue","The Perl5 Porters Mailing List"),
		print_table_row(2, "Thread::Semaphore","The Perl5 Porters Mailing List"),
		print_table_row(2, "Thread::Signal","The Perl5 Porters Mailing List"),
		print_table_row(2, "Thread::Specific","The Perl5 Porters Mailing List"),
		print_table_row(2, "Tie::Array","The Perl5 Porters Mailing List"),
		print_table_row(2, "Tie::File","Mark Jason Dominus"),
		print_table_row(2, "Tie::Handle","Steffen Beyer"),
		print_table_row(2, "Tie::Hash","The Perl5 Porters Mailing List"),
		print_table_row(2, "Tie::Memoize","Nicholas Clark"),
		print_table_row(2, "Tie::RefHash","Nicholas Clark"),
		print_table_row(2, "Tie::Scalar","The Perl5 Porters Mailing List"),
		print_table_row(2, "Tie::SubstrHash","Larry Wall. Author of Perl. Busy man."),
		print_table_row(2, "Time::HiRes","Jarkko Hietaniemi"),
		print_table_row(2, "Time::Local","The Perl5 Porters Mailing List"),
		print_table_row(2, "Time::gmtime","Tom Christiansen"),
		print_table_row(2, "Time::localtime","Tom Christiansen"),
		print_table_row(2, "Time::tm","Nicholas Clark"),
		print_table_row(2, "UNIVERSAL","The Perl5 Porters Mailing List"),
		print_table_row(2, "Unicode::Collate","SADAHIRO Tomoyuki"),
		print_table_row(2, "Unicode::Normalize","SADAHIRO Tomoyuki"),
		print_table_row(2, "Unicode::UCD","Nicholas Clark"),
		print_table_row(2, "User::grent","Tom Christiansen"),
		print_table_row(2, "User::pwent","Tom Christiansen"),
		print_table_row(2, "VMS::DCLsym","Nicholas Clark"),
		print_table_row(2, "VMS::Filespec","Charles Bailey"),
		print_table_row(2, "VMS::Stdio","Nicholas Clark"),
		print_table_row(2, "XS::APItest","Nicholas Clark"),
		print_table_row(2, "XS::Typemap","Nicholas Clark"),
		print_table_row(2, "base","Michael G Schwern"),
		print_table_row(2, "bigint","Tels"),
		print_table_row(2, "bignum","Tels"),
		print_table_row(2, "bigrat","Tels"),
		print_table_row(2, "encoding","Dan Kogai"),
		print_table_row(2, "fields","Michael G Schwern"),
		print_table_row(2, "if","Ilya Zakharevich"),
		print_table_end(),
	
		# Perldoc
		print_table_start(),
		print_table_colspan_header(2, "Perl Documentation"),
		print_table_row(2, "Perldoc maintainer", "Sean M. Burke"),
		print_table_row(2, "Past Perldoc contributers", "Kenneth Albanowski, Andy Dougherty, and many others"),
		print_table_end(),

		# CPAN 
		print_table_start(),
		print_table_header(1, "CPAN Maintainer"),
		print_table_row(1, "Jarkko Hietaniemi"),
		print_table_end(),

		# Website Team 
		print_table_start(),
		print_table_header(1, "Perl Website Team"),
		print_table_row(1, "Lisa Wolfisch, Robert Spier, and Ask Bjoern Hansen"),
		print_table_end();

  }
    
1,
